#!/bin/bash
#
#   USAGE:  buildGeant4.sh [gcc46|supcl|f1] [debug|opt|prof]

basequal=${1}
extras=${2}

if [ -z ${basequal} ]
then
    basequal=gcc46
fi

if [ "${extras}" = "debug" ]
then
    qual=${basequal}:debug
    qdir=${basequal}-debug
elif [ "${extras}" = "opt" ]
then
    qual=${basequal}:opt
    qdir=${basequal}-opt
elif [ "${extras}" = "prof" ]
then
    qual=${basequal}:prof
    qdir=${basequal}-prof
else
    qual=${basequal}
    qdir=${basequal}
fi


source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi
g4dir=${PRODUCTS}/geant4/v4_9_5/${flvr}-${qdir}

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

mkdir -p ${g4dir}
if [ ! -d ${g4dir} ]
then
   echo "ERROR: failed to create ${g4dir}"
   exit 1
fi

# declare and then setup geant4
echo "Declaring geant4 v4_9_5 for flavor ${flvr}"
if [ ${OS} = "Darwin" ]
then
   ups declare geant4 v4_9_5 -r geant4/v4_9_5 -2 -m geant4.table -q ${qual}
else 
   ups declare geant4 v4_9_5 -r geant4/v4_9_5 -4 -m geant4.table -q ${qual}
fi

echo "calling ups build geant4 v4_9_5 -q ${qual}"

ups build geant4 v4_9_5 -q ${qual}

# this should not complain
echo "Finished building geant4 v4_9_5 ${flvr} -q ${qual}"
setup geant4 v4_9_5 -q ${qual}

if [ ! -d ${G4LIB} ]
then
   echo "ERROR: failed to create ${G4LIB}"
   echo "       Something is very wrong"
   exit 1
fi
echo "G4LIB is ${G4LIB}"

exit 0
